.. _spkg_palp:

palp: A package for Analyzing Lattice Polytopes
===============================================

Description
-----------

A Package for Analyzing Lattice Polytopes (PALP) is a set of C programs
for calculations with lattice polytopes and applications to toric
geometry.

It contains routines for vertex and facet enumeration, computation of
incidences and symmetries, as well as completion of the set of lattice
points in the convex hull of a given set of points. In addition, there
are procedures specialised to reflexive polytopes such as the
enumeration of reflexive subpolytopes, and applications to toric
geometry and string theory, like the computation of Hodge data and
fibration structures for toric Calabi-Yau varieties. The package is well
tested and optimised in speed as it was used for time consuming tasks
such as the classification of reflexive polyhedra in 4 dimensions and
the creation and manipulation of very large lists of 5-dimensional
polyhedra.

While originally intended for low-dimensional applications, the
algorithms work in any dimension and our key routine for vertex and
facet enumeration compares well with existing packages.

License
-------

-  When released, GPL 2 was in force.
-  There is a link to a web page, which now points to GPL 3, but would
   have pointed to GPL 2 at the time the package was released.

-  Therefore one can deduce the authors were happy for this to be
   released under GPL 2 or a later version.


Upstream Contact
----------------

-  Author: Harald Skarke (skarke@maths.ox.ac.uk)
-  Home page: http://hep.itp.tuwien.ac.at/~kreuzer/CY/CYpalp.html


Type
----

standard


Dependencies
------------



Version Information
-------------------

package-version.txt::

    2.21

See https://repology.org/project/palp/versions

Installation commands
---------------------

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i palp

.. tab:: Arch Linux:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S palp

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install palp

.. tab:: Debian/Ubuntu:

   .. CODE-BLOCK:: bash

       $ sudo apt-get install palp

.. tab:: Fedora/Redhat/CentOS:

   .. CODE-BLOCK:: bash

       $ sudo dnf install palp

.. tab:: Nixpkgs:

   .. CODE-BLOCK:: bash

       $ nix-env -f \'\<nixpkgs\>\' --install --attr palp

.. tab:: Void Linux:

   .. CODE-BLOCK:: bash

       $ sudo xbps-install palp


If the system package is installed, ``./configure`` will check if it can be used.
